==> luna_cow-0.5.33-py3-none-any.whl: cow/web/utils.py <==
"""
Module realizes utils for base handler.
"""
from typing import Any, Callable, Optional, Set, Union

import chardet
import fastjsonschema
import msgpack
import ujson as json
from jsonschema import SchemaError, ValidationError, validate

from ..errors.errors import Error
from ..errors.exception import VLException

# list valid content types for json
VALID_REQUEST_JSON_CONTENT_TYPES: Set[str] = {"application/json", "application/octet-stream"}


def decodeBytes(body: bytes, encoding: Optional[str] = None) -> str:
    """
    Decode request body bytes.

    Args:
        body: request body
        encoding: encoding type from request (e.g. `request.charset`)

    Returns:
        parsed text
    """
    if encoding is None:
        encoding = "utf-8"
    try:
        content = str(body, encoding=encoding)
    except (UnicodeDecodeError, LookupError):
        # encoding type will be guessed using "chardet"
        encoding = chardet.detect(body)["encoding"]
        try:
            content = str(body, encoding=encoding, errors="replace")
        except (LookupError, TypeError):
            # A LookupError is raised if the encoding was not found which could
            # indicate a misspelling or similar mistake.
            #
            # A TypeError can be raised if encoding is None
            #
            # So we try blindly encoding.
            content = str(body, errors="replace")
    return content


def isValidJsonRequestContentType(inputContentType: str) -> bool:
    """
    Check if Content-Type is valid

    Args:
        inputContentType: Content-Type header value received from client

    Returns:
        true if the header is correct

    """
    return inputContentType in VALID_REQUEST_JSON_CONTENT_TYPES


def loadJson(text: str) -> Any:
    """
    Load python objects from JSON.

    Args:
        text: text to parse

    Returns:
        python objects (Lists and Dicts)

    Raises:
        VLException(Error.RequestNotContainsJson, 400): if failed  to load json
    """
    try:
        return json.loads(text)  # pylint: disable-msg=c-extension-no-member
    except ValueError as exc:
        raise VLException(Error.RequestNotContainsJson, 400, isCriticalError=False) from exc


def loadMsgPack(body: bytes, **kwargs):
    """
    Load python objects from MSGPACK.

    Args:
        body: body to parse

    Returns:
        python objects (Lists and Dicts)

    Raises:
        VLException(Error.RequestNotContainsJson, 400): if failed to load data
    """
    try:
        return msgpack.loads(body, raw=False, **kwargs)
    except (ValueError, msgpack.UnpackException) as exc:
        raise VLException(Error.BadInputData.format("Msgpack unpack failed"), 400, isCriticalError=False) from exc


def validateJson(data: Union[int, dict, list], schema: Union[dict, Callable], useJsonSchema: bool = True) -> None:
    """
    Validate json.

    Args:
        data: json for validation
        schema: json schema if using jsonschema, compiled schema if using fastjsonschema
                fastjsonschema doesn't full support dependencies in schemas at the moment
        useJsonSchema: flag to use jsonschema instead of fastjsonschema (doesn't support dependencies at the moment)
    Raises:
        VLException(Error.BadInputJson, 400): if failed  to validate schema
    """
    if useJsonSchema:
        try:
            validate(data, schema)
        except (ValidationError, SchemaError) as exc:
            path = ""
            for count, subPath in enumerate(exc.path):
                path += str(subPath)
                if count != len(exc.path) - 1:
                    path += "."

            error = Error.BadInputJson.format(path, exc.message)
            raise VLException(error, 400, isCriticalError=False) from exc
    else:
        try:
            schema(data)
        except fastjsonschema.JsonSchemaValueException as exc:
            ePath = exc.path[1:] if exc.path[0] == "data" else exc.path
            path = "".join([f"[{subPath}]" if subPath.isdigit() else f".{subPath}" for subPath in ePath]).lstrip(".")

            msg = exc.message
            if exc.message.startswith("data."):
                msg = msg[5:]
            if exc.message.startswith("data["):
                msg = msg[4:]

            error = Error.BadInputJson.format(path, msg)
            raise VLException(error, 400, isCriticalError=False) from exc

==> luna_cow-0.5.51-py3-none-any.whl: cow/web/utils.py <==
"""
Module realizes utils for base handler.
"""
from typing import Any, Callable, Optional, Set, Union

import chardet
import fastjsonschema
import msgpack
import ujson as json
from jsonschema import SchemaError, ValidationError, validate

from ..errors.errors import Error
from ..errors.exception import VLException

# list valid content types for json
VALID_REQUEST_JSON_CONTENT_TYPES: Set[str] = {"application/json", "application/octet-stream"}


def decodeBytes(body: bytes, encoding: Optional[str] = None) -> str:
    """
    Decode request body bytes.

    Args:
        body: request body
        encoding: encoding type from request (e.g. `request.charset`)

    Returns:
        parsed text
    """
    if encoding is None:
        encoding = "utf-8"
    try:
        content = str(body, encoding=encoding)
    except (UnicodeDecodeError, LookupError):
        # encoding type will be guessed using "chardet"
        encoding = chardet.detect(body)["encoding"]
        try:
            content = str(body, encoding=encoding, errors="replace")
        except (LookupError, TypeError):
            # A LookupError is raised if the encoding was not found which could
            # indicate a misspelling or similar mistake.
            #
            # A TypeError can be raised if encoding is None
            #
            # So we try blindly encoding.
            content = str(body, errors="replace")
    return content


def isValidJsonRequestContentType(inputContentType: str) -> bool:
    """
    Check if Content-Type is valid

    Args:
        inputContentType: Content-Type header value received from client

    Returns:
        true if the header is correct

    """
    return inputContentType in VALID_REQUEST_JSON_CONTENT_TYPES


def loadJson(text: str) -> Any:
    """
    Load python objects from JSON.

    Args:
        text: text to parse

    Returns:
        python objects (Lists and Dicts)

    Raises:
        VLException(Error.RequestNotContainsJson, 400): if failed  to load json
    """
    try:
        return json.loads(text)  # pylint: disable-msg=c-extension-no-member
    except ValueError as exc:
        raise VLException(Error.RequestNotContainsJson, 400, isCriticalError=False) from exc


def loadMsgPack(body: bytes, **kwargs):
    """
    Load python objects from MSGPACK.

    Args:
        body: body to parse

    Returns:
        python objects (Lists and Dicts)

    Raises:
        VLException(Error.RequestNotContainsJson, 400): if failed to load data
    """
    try:
        return msgpack.loads(body, raw=False, **kwargs)
    except (ValueError, msgpack.UnpackException) as exc:
        raise VLException(Error.BadInputData.format("Msgpack unpack failed"), 400, isCriticalError=False) from exc


def validateJson(
    contentType: str, data: Union[int, dict, list], schema: Union[dict, Callable], useJsonSchema: bool = True
) -> None:
    """
    Validate json or msgpack.

    Args:
        contentType: data content type
        data: json for validation
        schema: json schema if using jsonschema, compiled schema if using fastjsonschema
                fastjsonschema doesn't full support dependencies in schemas at the moment
        useJsonSchema: flag to use jsonschema instead of fastjsonschema (doesn't support dependencies at the moment)
    Raises:
        VLException(Error.BadInputJson, 400): if failed  to validate schema
        VLException(Error.BadInputMsgpack, 400): if failed  to validate schema
    """
    if contentType == "application/msgpack":
        errorClass = Error.BadInputMsgpack
    else:
        errorClass = Error.BadInputJson
    if useJsonSchema:
        try:
            validate(data, schema)
        except (ValidationError, SchemaError) as exc:
            path = ""
            for count, subPath in enumerate(exc.path):
                path += str(subPath)
                if count != len(exc.path) - 1:
                    path += "."

            error = errorClass.format(path, exc.message)
            raise VLException(error, 400, isCriticalError=False) from exc
    else:
        try:
            schema(data)
        except fastjsonschema.JsonSchemaValueException as exc:
            ePath = exc.path[1:] if exc.path[0] == "data" else exc.path
            path = "".join([f"[{subPath}]" if subPath.isdigit() else f".{subPath}" for subPath in ePath]).lstrip(".")

            msg = exc.message
            if exc.message.startswith("data."):
                msg = msg[5:]
            if exc.message.startswith("data["):
                msg = msg[4:]

            error = errorClass.format(path, msg)
            raise VLException(error, 400, isCriticalError=False) from exc
